@@ -26,7 +26,7 @@ use super::python::*;
 use crate::py_err::ResultTClientErrorExt;
 use crate::server::PySyncServer;
 
-#[pyclass]
+#[pyclass(module = "perspective")]
 #[derive(Clone)]
 pub struct ProxySession(perspective_client::ProxySession);
 
@@ -81,7 +81,7 @@ trait PyFutureExt: Future {
 impl<F: Future> PyFutureExt for F {}
 
 #[doc = crate::inherit_docs!("client.md")]
-#[pyclass(subclass)]
+#[pyclass(subclass, module = "perspective")]
 pub struct Client(pub(crate) PyClient);
 
 #[pymethods]
@@ -147,7 +147,7 @@ impl Client {
 }
 
 #[doc = crate::inherit_docs!("table.md")]
-#[pyclass(subclass, name = "Table")]
+#[pyclass(subclass, name = "Table", module = "perspective")]
 pub struct Table(PyTable);
 
 assert_table_api!(Table);
@@ -272,7 +272,7 @@ impl Table {
 }
 
 #[doc = crate::inherit_docs!("view.md")]
-#[pyclass(subclass, name = "View")]
+#[pyclass(subclass, name = "View", module = "perspective")]
 pub struct View(PyView);
 
 assert_view_api!(View);
@@ -307,6 +307,12 @@ impl View {
         self.0.to_json_string(window).py_block_on(py)
     }
 
+    #[doc = crate::inherit_docs!("view/to_ndjson.md")]
+    #[pyo3(signature = (**window))]
+    pub fn to_ndjson(&self, py: Python<'_>, window: Option<Py<PyDict>>) -> PyResult<String> {
+        self.0.to_ndjson(window).py_block_on(py)
+    }
+
     #[pyo3(signature = (**window))]
     pub fn to_records<'a>(
         &self,
@@ -346,11 +352,25 @@ impl View {
         self.0.to_csv(window).py_block_on(py)
     }
 
+    #[doc = include_str!("../../docs/client/to_pandas.md")]
     #[pyo3(signature = (**window))]
+    // #[deprecated(since="3.2.0", note="Please use `View::to_pandas`")]
     pub fn to_dataframe(&self, py: Python<'_>, window: Option<Py<PyDict>>) -> PyResult<Py<PyAny>> {
         self.0.to_dataframe(window).py_block_on(py)
     }
 
+    #[doc = include_str!("../../docs/client/to_pandas.md")]
+    #[pyo3(signature = (**window))]
+    pub fn to_pandas(&self, py: Python<'_>, window: Option<Py<PyDict>>) -> PyResult<Py<PyAny>> {
+        self.0.to_dataframe(window).py_block_on(py)
+    }
+
+    #[doc = include_str!("../../docs/client/to_polars.md")]
+    #[pyo3(signature = (**window))]
+    pub fn to_polars(&self, py: Python<'_>, window: Option<Py<PyDict>>) -> PyResult<Py<PyAny>> {
+        self.0.to_polars(window).py_block_on(py)
+    }
+
     #[doc = crate::inherit_docs!("view/to_arrow.md")]
     #[pyo3(signature = (**window))]
     pub fn to_arrow(&self, py: Python<'_>, window: Option<Py<PyDict>>) -> PyResult<Py<PyBytes>> {
